@@ -3,489 +3,537 @@
 <context>
     <name>ConfigDialog</name>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="53"/>
         <source>Behavior</source>
         <translation>Поведение</translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="53"/>
         <source>Automatically save documents</source>
         <translation>Автоматически сохранять документы</translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="53"/>
         <source>Restore window geometry</source>
         <translation>Сохранять геометрию окна</translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="53"/>
         <source>Restore live preview state</source>
         <translation>Сохранять состояние живого просмотра</translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="53"/>
         <source>Open external links in ReText window</source>
         <translation>Открывать внешние ссылки в окне ReText</translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="53"/>
         <source>Open unknown files in plain text mode</source>
         <translation>Открывать неизвестные файлы в режиме простого текста</translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="53"/>
+        <source>Markdown extensions (comma-separated)</source>
+        <translation>Расширения Markdown (разделённые запятыми)</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="53"/>
         <source>Editor</source>
         <translation>Редактор</translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="53"/>
         <source>Highlight current line</source>
         <translation>Подсвечивать текущую строку</translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="53"/>
         <source>Show line numbers</source>
         <translation>Показывать номера строк</translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="53"/>
         <source>Tab key inserts spaces</source>
         <translation>Tab вставляет пробелы</translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="53"/>
         <source>Tabulation width</source>
         <translation>Ширина табуляции</translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="53"/>
         <source>Display right margin at column</source>
         <translation>Показывать разделитель в столбце</translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="53"/>
         <source>Interface</source>
         <translation>Внешний вид</translation>
     </message>
     <message>
-        <location filename="config.py" line="24"/>
+        <location filename="config.py" line="53"/>
         <source>Icon theme name</source>
         <translation>Тема значков</translation>
     </message>
+    <message>
+        <location filename="config.py" line="53"/>
+        <source>Color scheme file</source>
+        <translation>Файл с цветовой схемой</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="53"/>
+        <source>Stylesheet file</source>
+        <translation>Файл стиля Qt</translation>
+    </message>
+</context>
+<context>
+    <name>FileSelectButton</name>
+    <message>
+        <location filename="config.py" line="21"/>
+        <source>(none)</source>
+        <translation>(не выбран)</translation>
+    </message>
+    <message>
+        <location filename="config.py" line="28"/>
+        <source>Select file to open</source>
+        <translation>Выберите файл для открытия</translation>
+    </message>
 </context>
 <context>
     <name>LocaleDialog</name>
     <message>
-        <location filename="dialogs.py" line="34"/>
+        <location filename="dialogs.py" line="32"/>
         <source>Enter locale name (example: en_US)</source>
-        <translation type="unfinished"></translation>
+        <translation>Введите код локали (например: en_US)</translation>
     </message>
     <message>
-        <location filename="dialogs.py" line="39"/>
+        <location filename="dialogs.py" line="37"/>
         <source>Set as default</source>
-        <translation type="unfinished"></translation>
+        <translation>Установить по умолчанию</translation>
     </message>
 </context>
 <context>
     <name>ReTextWindow</name>
     <message>
-        <location filename="window.py" line="103"/>
-        <source>Open</source>
-        <translation>Открыть</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="109"/>
-        <source>Save</source>
-        <translation>Сохранить</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="115"/>
-        <source>Print</source>
-        <translation>Распечатать</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="126"/>
-        <source>Preview</source>
-        <translation>Просмотр</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="214"/>
-        <source>Tags</source>
-        <translation>Теги</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="218"/>
-        <source>Symbols</source>
-        <translation>Символы</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1038"/>
-        <source>HTML files (*.html *.htm)</source>
-        <translation>Файлы HTML (*.html *.htm)</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1038"/>
-        <source>Save file</source>
-        <translation>Сохранить файл</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="113"/>
-        <source>Save as</source>
-        <translation>Сохранить как</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="145"/>
-        <source>Quit</source>
-        <translation>Выход</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="182"/>
-        <source>About Qt</source>
-        <translation>О Qt</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="231"/>
-        <source>File</source>
-        <translation>Файл</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="232"/>
-        <source>Edit</source>
-        <translation>Правка</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="233"/>
-        <source>Help</source>
-        <translation>Справка</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="247"/>
-        <source>Export</source>
-        <translation>Экспорт</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="92"/>
+        <location filename="window.py" line="61"/>
         <source>File toolbar</source>
         <translation>Панель файла</translation>
     </message>
     <message>
-        <location filename="window.py" line="94"/>
+        <location filename="window.py" line="63"/>
         <source>Edit toolbar</source>
         <translation>Панель редактирования</translation>
     </message>
     <message>
-        <location filename="window.py" line="1059"/>
+        <location filename="window.py" line="65"/>
+        <source>Search toolbar</source>
+        <translation>Панель поиска</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="69"/>
+        <source>New</source>
+        <translation>Новый</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="72"/>
+        <source>Open</source>
+        <translation>Открыть</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="75"/>
+        <source>Set encoding</source>
+        <translation>Установить кодировку</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="78"/>
+        <source>Reload</source>
+        <translation>Загрузить заново</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="80"/>
+        <source>Save</source>
+        <translation>Сохранить</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="84"/>
+        <source>Save as</source>
+        <translation>Сохранить как</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="86"/>
+        <source>Next tab</source>
+        <translation>Следующая вкладка</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="88"/>
+        <source>Previous tab</source>
+        <translation>Предыдущая вкладка</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="90"/>
+        <source>Print</source>
+        <translation>Распечатать</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="93"/>
+        <source>Print preview</source>
+        <translation>Предпросмотр печати</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="95"/>
+        <source>View HTML code</source>
+        <translation>Просмотр кода HTML</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="96"/>
+        <source>Change default font</source>
+        <translation>Изменить стандартный шрифт</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="97"/>
+        <source>Find text</source>
+        <translation>Поиск текста</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="101"/>
+        <source>Preview</source>
+        <translation>Просмотр</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="110"/>
+        <source>Live preview</source>
+        <translation>Живой просмотр</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="112"/>
+        <source>Table mode</source>
+        <translation>Режим редактирования таблиц</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="114"/>
+        <source>Fullscreen mode</source>
+        <translation>Полноэкранный режим</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="574"/>
+        <source>Preferences</source>
+        <translation>Настройки</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="122"/>
+        <source>Quit</source>
+        <translation>Выход</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="125"/>
+        <source>Undo</source>
+        <translation>Отменить действие</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="127"/>
+        <source>Redo</source>
+        <translation>Повторить действие</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="129"/>
+        <source>Copy</source>
+        <translation>Копировать</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="131"/>
+        <source>Cut</source>
+        <translation>Вырезать</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="133"/>
+        <source>Paste</source>
+        <translation>Вставить</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="143"/>
+        <source>Enable</source>
+        <translation>Включить</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="144"/>
+        <source>Set locale</source>
+        <translation>Установить локаль</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="145"/>
+        <source>Plain text</source>
+        <translation>Простой текст</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="146"/>
+        <source>Use WebKit renderer</source>
+        <translation>Использовать движок WebKit</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="148"/>
+        <source>Generate webpages</source>
+        <translation>Создать веб-страницы</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="149"/>
+        <source>Show</source>
+        <translation>Показать</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="150"/>
+        <source>Next</source>
+        <translation>Следующее</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="152"/>
+        <source>Previous</source>
+        <translation>Предыдущее</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="154"/>
+        <source>Get help online</source>
+        <translation>Получить помощь в интернете</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="155"/>
+        <source>About %s</source>
+        <comment>Example of final string: About ReText</comment>
+        <translation>О %s</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="159"/>
+        <source>About Qt</source>
+        <translation>О Qt</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="179"/>
+        <source>Bold</source>
+        <translation>Полужирный</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="181"/>
+        <source>Italic</source>
+        <translation>Курсив</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="183"/>
+        <source>Underline</source>
+        <translation>Подчёркивание</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="191"/>
+        <source>Tags</source>
+        <translation>Теги</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="195"/>
+        <source>Symbols</source>
+        <translation>Символы</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="209"/>
+        <source>File</source>
+        <translation>Файл</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="210"/>
+        <source>Edit</source>
+        <translation>Правка</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="211"/>
+        <source>Help</source>
+        <translation>Справка</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="214"/>
+        <source>Open recent</source>
+        <translation>Открыть последние</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="217"/>
+        <source>Directory</source>
+        <translation>Папка</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="229"/>
+        <source>Export</source>
+        <translation>Экспорт</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="250"/>
+        <source>Spell check</source>
+        <translation>Проверка орфографии</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="258"/>
+        <source>Default markup</source>
+        <translation>Язык разметки по умолчанию</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="261"/>
+        <source>Formatting</source>
+        <translation>Форматирование</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="299"/>
+        <source>Search</source>
+        <translation>Поиск</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="301"/>
+        <source>Case sensitively</source>
+        <translation>Учитывать регистр</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1128"/>
+        <source>New document</source>
+        <translation>Новый документ</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="648"/>
+        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
+        <translation>Не удалось обработать содержимое файла, убедитесь, что установлен &lt;a href=&quot;%s&quot;&gt;необходимый модуль&lt;/a&gt;!</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="746"/>
+        <source>Please, save the file somewhere.</source>
+        <translation>Сначала сохраните файл.</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="731"/>
+        <source>Failed to copy default template, please create template.html manually.</source>
+        <translation>Не удалось скопировать шаблон по умолчанию, создайте template.html вручную.</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="735"/>
+        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
+        <translation>Веб-страницы сохранены в папке &lt;code&gt;html&lt;/code&gt;.</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="737"/>
+        <source>Show directory</source>
+        <translation>Открыть папку</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="865"/>
+        <source>Select one or several files to open</source>
+        <translation>Выберите один или несколько файлов для открытия</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="865"/>
+        <source>Supported files</source>
+        <translation>Поддерживаемые файлы</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="865"/>
+        <source>All files (*)</source>
+        <translation>Все файлы (*)</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="924"/>
+        <source>Select file encoding from the list:</source>
+        <translation>Выберите кодировку файла из списка:</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="949"/>
+        <source>Plain text (*.txt)</source>
+        <translation>Простой текст (*.txt)</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="952"/>
+        <source>%s files</source>
+        <comment>Example of final string: Markdown files</comment>
+        <translation>Файлы %s</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1027"/>
+        <source>Save file</source>
+        <translation>Сохранить файл</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="972"/>
+        <source>Cannot save to file because it is read-only!</source>
+        <translation>Невозможно сохранить в файл, так как он доступен только для чтения!</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1017"/>
+        <source>Export document to ODT</source>
+        <translation>Экспортировать документ как ODT</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1017"/>
+        <source>OpenDocument text files (*.odt)</source>
+        <translation>Файлы текста OpenDocument (*.odt)</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1027"/>
+        <source>HTML files (*.html *.htm)</source>
+        <translation>Файлы HTML (*.html *.htm)</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1049"/>
         <source>Export document to PDF</source>
         <translation>Экспортировать документ как PDF</translation>
     </message>
     <message>
-        <location filename="window.py" line="1059"/>
+        <location filename="window.py" line="1049"/>
         <source>PDF files (*.pdf)</source>
         <translation>Файлы PDF (*.pdf)</translation>
     </message>
     <message>
-        <location filename="window.py" line="1191"/>
+        <location filename="window.py" line="1066"/>
+        <source>Print document</source>
+        <translation>Распечатать документ</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1087"/>
+        <source>Export document</source>
+        <translation>Экспортировать документ</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1106"/>
+        <source>Failed to execute the command:</source>
+        <translation>Невозможно запустить команду:</translation>
+    </message>
+    <message>
+        <location filename="window.py" line="1187"/>
         <source>The document has been modified.
 Do you want to save your changes?</source>
         <translation>Документ был изменён.
 Сохранить изменения?</translation>
     </message>
     <message>
-        <location filename="window.py" line="148"/>
-        <source>Undo</source>
-        <translation>Отменить действие</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="150"/>
-        <source>Redo</source>
-        <translation>Повторить действие</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="152"/>
-        <source>Copy</source>
-        <translation>Копировать</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="154"/>
-        <source>Cut</source>
-        <translation>Вырезать</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="156"/>
-        <source>Paste</source>
-        <translation>Вставить</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1135"/>
-        <source>New document</source>
-        <translation>Новый документ</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="880"/>
-        <source>All files (*)</source>
-        <translation>Все файлы (*)</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="100"/>
-        <source>New</source>
-        <translation>Новый</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="236"/>
-        <source>Open recent</source>
-        <translation>Открыть последние</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="168"/>
-        <source>Plain text</source>
-        <translation>Простой текст</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1029"/>
-        <source>OpenDocument text files (*.odt)</source>
-        <translation>Файлы текста OpenDocument (*.odt)</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1029"/>
-        <source>Export document to ODT</source>
-        <translation>Экспортировать документ как ODT</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="120"/>
-        <source>View HTML code</source>
-        <translation>Просмотр кода HTML</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1215"/>
+        <location filename="window.py" line="1211"/>
         <source>HTML code</source>
         <translation>код HTML</translation>
     </message>
     <message>
-        <location filename="window.py" line="118"/>
-        <source>Print preview</source>
-        <translation>Предпросмотр печати</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1075"/>
-        <source>Print document</source>
-        <translation>Распечатать документ</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="135"/>
-        <source>Live preview</source>
-        <translation>Живой просмотр</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="754"/>
-        <source>Webpages saved in &lt;code&gt;html&lt;/code&gt; directory.</source>
-        <translation>Веб-страницы сохранены в папке &lt;code&gt;html&lt;/code&gt;.</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="765"/>
-        <source>Please, save the file somewhere.</source>
-        <translation>Сначала сохраните файл.</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="171"/>
-        <source>Generate webpages</source>
-        <translation>Создать веб-страницы</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="962"/>
-        <source>Plain text (*.txt)</source>
-        <translation>Простой текст (*.txt)</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="172"/>
-        <source>Show</source>
-        <translation>Показать</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="239"/>
-        <source>Directory</source>
-        <translation>Папка</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="880"/>
-        <source>Supported files</source>
-        <translation>Поддерживаемые файлы</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="121"/>
-        <source>Change default font</source>
-        <translation>Изменить стандартный шрифт</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1096"/>
-        <source>Export document</source>
-        <translation>Экспортировать документ</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="166"/>
-        <source>Enable</source>
-        <translation>Включить</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="167"/>
-        <source>Set locale</source>
-        <translation>Установить локаль</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="269"/>
-        <source>Spell check</source>
-        <translation>Проверка орфографии</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="137"/>
-        <source>Fullscreen mode</source>
-        <translation>Полноэкранный режим</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="96"/>
-        <source>Search toolbar</source>
-        <translation>Панель поиска</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="122"/>
-        <source>Find text</source>
-        <translation>Поиск текста</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="173"/>
-        <source>Next</source>
-        <translation>Следующее</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="175"/>
-        <source>Previous</source>
-        <translation>Предыдущее</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="317"/>
-        <source>Search</source>
-        <translation>Поиск</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="319"/>
-        <source>Case sensitively</source>
-        <translation>Учитывать регистр</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1226"/>
-        <source>Author: Dmitry Shachnev, 2011</source>
-        <translation>Автор: Dmitry Shachnev, 2011</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1226"/>
-        <source>Website</source>
-        <translation>Веб-сайт</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1226"/>
-        <source>Markdown syntax</source>
-        <translation>Синтаксис Markdown</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1226"/>
-        <source>reStructuredText syntax</source>
-        <translation>Синтаксис reStructuredText</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1226"/>
+        <location filename="window.py" line="1222"/>
         <source>Simple but powerful editor for Markdown and reStructuredText</source>
         <translation>Простой, но мощный редактор для Markdown и reStructuredText</translation>
     </message>
     <message>
-        <location filename="window.py" line="880"/>
-        <source>Select one or several files to open</source>
-        <translation>Выберите один или несколько файлов для открытия</translation>
+        <location filename="window.py" line="1222"/>
+        <source>Author: Dmitry Shachnev, 2011</source>
+        <translation>Автор: Dmitry Shachnev, 2011</translation>
     </message>
     <message>
-        <location filename="window.py" line="177"/>
-        <source>Get help online</source>
-        <translation>Получить помощь в интернете</translation>
+        <location filename="window.py" line="1222"/>
+        <source>Website</source>
+        <translation>Веб-сайт</translation>
     </message>
     <message>
-        <location filename="window.py" line="756"/>
-        <source>Show directory</source>
-        <translation>Открыть папку</translation>
+        <location filename="window.py" line="1222"/>
+        <source>Markdown syntax</source>
+        <translation>Синтаксис Markdown</translation>
     </message>
     <message>
-        <location filename="window.py" line="984"/>
-        <source>Cannot save to file because it is read-only!</source>
-        <translation>Невозможно сохранить в файл, так как он доступен только для чтения!</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="202"/>
-        <source>Bold</source>
-        <translation>Полужирный</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="204"/>
-        <source>Italic</source>
-        <translation>Курсив</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="206"/>
-        <source>Underline</source>
-        <translation>Подчёркивание</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="280"/>
-        <source>Formatting</source>
-        <translation>Форматирование</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="178"/>
-        <source>About %s</source>
-        <comment>Example of final string: About ReText</comment>
-        <translation>О %s</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="169"/>
-        <source>Use WebKit renderer</source>
-        <translation>Использовать движок WebKit</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="1114"/>
-        <source>Failed to execute the command:</source>
-        <translation>Невозможно запустить команду:</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="965"/>
-        <source>%s files</source>
-        <comment>Example of final string: Markdown files</comment>
-        <translation>Файлы %s</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="750"/>
-        <source>Failed to copy default template, please create template.html manually.</source>
-        <translation>Не удалось скопировать шаблон по умолчанию, создайте template.html вручную.</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="661"/>
-        <source>Could not parse file contents, check if you have the &lt;a href=&quot;%s&quot;&gt;necessary module&lt;/a&gt; installed!</source>
-        <translation>Не удалось обработать содержимое файла, убедитесь, что установлен &lt;a href=&quot;%s&quot;&gt;необходимый модуль&lt;/a&gt;!</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="277"/>
-        <source>Default markup</source>
-        <translation>Язык разметки по умолчанию</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="586"/>
-        <source>Preferences</source>
-        <translation>Настройки</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="106"/>
-        <source>Set encoding</source>
-        <translation>Установить кодировку</translation>
-    </message>
-    <message>
-        <location filename="window.py" line="937"/>
-        <source>Select file encoding from the list:</source>
-        <translation>Выберите кодировку файла из списка:</translation>
+        <location filename="window.py" line="1222"/>
+        <source>reStructuredText syntax</source>
+        <translation>Синтаксис reStructuredText</translation>
     </message>
 </context>
 </TS>
